pub fn parent_path<'a>(path: &'a str, policy: &PathPolicy) -> Option<&'a str>Expand description
Return the direct parent slice when one exists under the given policy.
pub fn parent_path<'a>(path: &'a str, policy: &PathPolicy) -> Option<&'a str>Return the direct parent slice when one exists under the given policy.